"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var pascal_case_1 = require("pascal-case");
var isOperationDefinitionNode = function (node) { return node.kind === "OperationDefinition"; };
var TypedDocumentVisitor = /** @class */ (function () {
    function TypedDocumentVisitor(output, location, config) {
        var _this = this;
        this.output = output;
        this.location = location;
        this.config = config;
        this.Document = function (node) {
            var _a;
            var operationNodes = node.definitions.filter(isOperationDefinitionNode);
            var output = [];
            operationNodes.forEach(function (operationNode) {
                if (!operationNode.name) {
                    throw new Error("Operation must have a name");
                }
                var operationName = operationNode.name.value;
                var typeName = pascal_case_1.pascalCase(operationName);
                var typeNameSuffix = pascal_case_1.pascalCase(operationNode.operation);
                output.push("export const " + operationName + ": TypedDocumentNode<" + typeName + typeNameSuffix + ", " + typeName + typeNameSuffix + "Variables>;\n");
            });
            if (operationNodes.length === 1) {
                var operationName = (_a = operationNodes[0].name) === null || _a === void 0 ? void 0 : _a.value;
                output.push("export default " + operationName + ";\n");
            }
            _this.output.push(output.join(""));
            return false; // No need to traverse deeper
        };
    }
    return TypedDocumentVisitor;
}());
exports.default = TypedDocumentVisitor;
